@@ -236,7 +236,7 @@ class PluginUploader:
             templates_path = os.path.join(Path(__file__).parent,'jinja_templates')
             environment = Environment(loader=FileSystemLoader(templates_path))
             # These are all the procs which underneath, need to talk to the plugin code and therefore need all the imports available
-            for proc_template in ['API_LIMITS','APPLY','CONFIGURATION_FORM','CONNECTION_TEST','CONNECTION_FORM','CREATE_BILLING_EVENTS','NETWORK_ADDRESSES']:
+            for proc_template in ['API_LIMITS','APPLY','CONFIGURATION_FORM','CONNECTION_TEST','CONNECTION_FORM','CREATE_BILLING_EVENTS','NETWORK_ADDRESSES','RETRIEVE_SECRETS']:
                 template = environment.get_template(f'{proc_template}.sql.jinja')
                 content = template.render({
                     "plugin_fqn": plugin_fqn,
@@ -253,6 +253,15 @@ class PluginUploader:
                 setup_script.write(f"{content}\n")
             setup_script.write('call PLUGIN.CONFIGURE_APIS();\n')
 
+            # Look for a folder named 'functions', and if it exists, load all the functions in it
+            functions_path = os.path.join(plugin_directory,'udfs')
+            if os.path.exists(functions_path):
+                setup_script.write("create or alter versioned schema UDFS;\n")
+                print('Adding udfs')
+                for path in sorted(Path(functions_path).glob('*.sql')):
+                    with open(path, "r",encoding='utf-8') as udf:
+                        setup_script.write(udf.read()+"\n")
+
         print('Uploading setup script to stage')
         self.session.sql((f"PUT file://{install_script} @{database_name}.{schema_name}.{stage_name}/scripts OVERWRITE=TRUE AUTO_COMPRESS = FALSE\n")).collect()
         
